@@ -7,5 +7,6 @@ def GlobalConfig(request):
             'SITE_URL': settings.SITE_URL,
             'HJID': settings.HJID,
             'HJSV': settings.HJSV,
-            'DEBUG': ('false', 'true')[settings.DEBUG]
+            'DEBUG': ('false', 'true')[settings.DEBUG],
+            'FEATURES': ','.join(["'%s'" % i for i in request.session.get('features', [])])
             }
